Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(811)

Unified Diff: runtime/include/dart_debugger_api.h

Issue 11926026: Add function for one-time stop at function entry (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 7 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/bin/main.cc ('k') | runtime/vm/debugger.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/include/dart_debugger_api.h
===================================================================
--- runtime/include/dart_debugger_api.h (revision 17321)
+++ runtime/include/dart_debugger_api.h (working copy)
@@ -222,9 +222,9 @@
/**
* Sets a breakpoint at the entry of the given function. If class_name
* is the empty string, looks for a library function with the given
* name.
*
* Requires there to be a current isolate.
*
@@ -241,6 +241,21 @@
/**
+ * Sets a breakpoint at the entry of the given function. If class_name
+ * is the empty string, looks for a library function with the given
+ * name.
+ *
+ * Requires there to be a current isolate.
+ *
+ * \return A handle to the True object if no error occurs.
+ */
+DART_EXPORT Dart_Handle Dart_OneTimeBreakAtEntry(
+ Dart_Handle library,
+ Dart_Handle class_name,
+ Dart_Handle function_name);
+
+
+/**
* DEPRECATED -- use Dart_RemoveBreakpoint instead.
*
* Deletes the given \breakpoint.
@@ -222,9 +222,9 @@
/**
- * Sets a breakpoint at the entry of the given function. If class_name
- * is the empty string, looks for a library function with the given
- * name.
+ * Sets a one-time breakpoint at the entry of the given function.
+ * If class_name is the empty string, looks for a library function
+ * with the given name.
*
* Requires there to be a current isolate.
« no previous file with comments | « runtime/bin/main.cc ('k') | runtime/vm/debugger.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698